==> patch-3.8.7-ONex-OMS-wms-source-PHP5.3.tar.gz: ShopexErp/app/erpapi/lib/shop/response/components/order/master.php <==
<?php
/**
* 订单主表信息
*
* @author chenping<chenping@shopex.cn>
* @version $Id: master.php 2013-3-12 17:23Z
*/
class erpapi_shop_response_components_order_master extends erpapi_shop_response_components_order_abstract
{
    const _APP_NAME = 'ome';
    /**
     * 订单格式转换
     *
     * @return void
     * @author 
     **/
    public function convert()
    {
        $funcObj = kernel::single('ome_func');

        # 店铺
        $this->_platform->_newOrder['shop_id']   = $this->_platform->__channelObj->channel['shop_id'];
        $this->_platform->_newOrder['shop_type'] = $this->_platform->__channelObj->channel['shop_type'];

        # 订单主信息
        $this->_platform->_newOrder['order_bn']         = $this->_platform->_ordersdf['order_bn'];
        $this->_platform->_newOrder['cost_item']        = (float)$this->_platform->_ordersdf['cost_item'];
        $this->_platform->_newOrder['discount']         = (float)$this->_platform->_ordersdf['discount'];
        $this->_platform->_newOrder['total_amount']     = (float)$this->_platform->_ordersdf['total_amount'];
        $this->_platform->_newOrder['pmt_goods']        = (float)$this->_platform->_ordersdf['pmt_goods'];
        $this->_platform->_newOrder['pmt_order']        = (float)$this->_platform->_ordersdf['pmt_order'];
        $this->_platform->_newOrder['cur_amount']       = (float)$this->_platform->_ordersdf['cur_amount'];
        $this->_platform->_newOrder['score_u']          = (float)$this->_platform->_ordersdf['score_u'];
        $this->_platform->_newOrder['score_g']          = (float)$this->_platform->_ordersdf['score_g'];
        $this->_platform->_newOrder['currency']         = $this->_platform->_ordersdf['currency'] ? $this->_platform->_ordersdf['currency'] : 'CNY';
        $this->_platform->_newOrder['source']           = 'matrix';
        $this->_platform->_newOrder['status']           = $this->_platform->_ordersdf['status'];
        $this->_platform->_newOrder['weight']           = (float)$this->_platform->_ordersdf['weight'];
        $this->_platform->_newOrder['order_source']     = $this->_platform->_ordersdf['order_source'];
        $this->_platform->_newOrder['cur_rate']         = $this->_platform->_ordersdf['cur_rate'] ? $this->_platform->_ordersdf['cur_rate'] : 1;
        $this->_platform->_newOrder['title']            = $this->_platform->_ordersdf['title'];
        $this->_platform->_newOrder['coupons_name']     = $this->_platform->_ordersdf['coupons_name'];
        $this->_platform->_newOrder['createway']        = 'matrix';
        
        if (isset($this->_platform->_ordersdf['self_delivery'])) $this->_platform->_newOrder['self_delivery']        = $this->_platform->_ordersdf['self_delivery'];

        # 时间
        $this->_platform->_newOrder['download_time']    = time();
        $this->_platform->_newOrder['createtime']       = $funcObj->date2time($this->_platform->_ordersdf['createtime']);
        $outer_lastmodify = $this->_platform->_ordersdf['lastmodify'] ? $this->_platform->_ordersdf['lastmodify'] : time();
        $this->_platform->_newOrder['outer_lastmodify'] = $funcObj->date2time($outer_lastmodify);

        if ($this->_platform->_ordersdf['order_limit_time']) {
            $this->_platform->_newOrder['order_limit_time'] = $funcObj->date2time($this->_platform->_ordersdf['order_limit_time']);
        } else {
            $this->_platform->_newOrder['order_limit_time'] = time() + 60 * (app::get('ome')->getConf('ome.order.failtime'));
        }

        # 支付方式
        $payment_cfg             = $this->_platform->get_payment($this->_platform->_ordersdf['pay_bn'],$this->_platform->__channelObj->channel['node_type']);
        $this->_platform->_newOrder['pay_bn']      = $payment_cfg['pay_bn'];
        $this->_platform->_newOrder['pay_status'] = $this->_platform->_ordersdf['pay_status'];
        $this->_platform->_newOrder['payed']      = $this->_platform->_ordersdf['payed'];

        # 支付金额
        $this->_platform->_newOrder['payinfo']['pay_name']     = $this->_platform->_ordersdf['payinfo']['pay_name'];
        $this->_platform->_newOrder['payinfo']['cost_payment'] = $this->_platform->_ordersdf['payinfo']['cost_payment'];

        # 支付单结构
        $payment_list = isset($this->_platform->_ordersdf['payments']) ? $this->_platform->_ordersdf['payments'] : (array)$this->_platform->_ordersdf['payment_detail'];

        if ($payment_list && is_array($payment_list)) {
            $total_amount = $this->_platform->_ordersdf['total_amount'];

            $pay_status = '0';
            $payed      = '0.000';
            $paytime    = null;
            foreach ($payment_list as $key => $value) {
                $payed += $value['money'];

                if ($value['pay_time']) {
                    $paytime = kernel::single('ome_func')->date2time($value['pay_time']);
                }
            }

            if ($total_amount <= $payed) {
                $pay_status = '1';

                if (!$paytime) $paytime = time();
            } elseif ($payed <= 0) {
                $pay_status = '0';
            } else {
                if (!$paytime) $paytime = time();

                $comp = bccomp(round($payed,3), $total_amount,3);

                $pay_status = $comp < 0 ? '3' : '1';
            }

            $this->_platform->_newOrder['pay_status'] = $pay_status;
            $this->_platform->_newOrder['payed']      = $payed;
            
            if ($paytime)
                $this->_platform->_newOrder['paytime']    = $paytime;
        }

        #加入手动单拉订单_标记_防止自动审单 ExBOY
        $this->_platform->_newOrder['auto_combine']    = ($this->_platform->_ordersdf['auto_combine'] === false ? false : true);
    }

    public function update()
    {
        if (in_array($this->_platform->_tgOrder['pay_status'], array('6','7')) && in_array($this->_platform->_ordersdf['pay_status'], array('1','3','4','5'))) {
            $this->_platform->_newOrder['pause'] = 'false';
        }

        $master = array();

        if ($this->_platform->_ordersdf['order_limit_time']) {
            $order_limit_time = kernel::single('ome_func')->date2time($this->_platform->_ordersdf['order_limit_time']);
            if ($order_limit_time != $this->_platform->_tgOrder['order_limit_time'] && $this->_platform->_tgOrder['pay_status'] == '0') {
                $master['order_limit_time'] = $order_limit_time;
            }
        }

        $master['pay_status']                = $this->_platform->_ordersdf['pay_status'];
        $master['discount']                  = $this->_platform->_ordersdf['discount'];
        $master['pmt_goods']                 = $this->_platform->_ordersdf['pmt_goods'];
        $master['pmt_order']                 = $this->_platform->_ordersdf['pmt_order'];
        $master['total_amount']              = $this->_platform->_ordersdf['total_amount'];
        $master['cur_amount']                = $this->_platform->_ordersdf['cur_amount'];
        $master['payed']                     = $this->_platform->_ordersdf['payed'];
        $master['cost_item']                 = $this->_platform->_ordersdf['cost_item'];
        $master['coupons_name']              = $this->_platform->_ordersdf['coupons_name'];
        $master['is_tax']                    = $this->_platform->_ordersdf['is_tax'] ? $this->_platform->_ordersdf['is_tax'] : 'false';
        $master['tax_no']                    = $this->_platform->_ordersdf['tax_no'];
        $master['cost_tax']                  = $this->_platform->_ordersdf['cost_tax'];
        $master['tax_title']                 = $this->_platform->_ordersdf['tax_title'];
        $master['weight']                    = $this->_platform->_ordersdf['weight'];
        $master['title']                     = $this->_platform->_ordersdf['title'];
        $master['score_u']                   = $this->_platform->_ordersdf['score_u'];
        $master['score_g']                   = $this->_platform->_ordersdf['score_g'];
        $master['status']                    = $this->_platform->_ordersdf['status'];
        
        
        $payment_cfg = $this->_platform->get_payment($this->_platform->_ordersdf['pay_bn'],$this->_platform->__channelObj->channel['node_type']);
        $master['pay_bn'] = $payment_cfg['pay_bn'];

        # 支付单结构
        $payment_list = isset($this->_platform->_ordersdf['payments']) ? $this->_platform->_ordersdf['payments'] : array($this->_platform->_ordersdf['payment_detail']);
        if ($payment_list 
            && is_array($payment_list) 
            && $this->_platform->_ordersdf['payed'] >= $this->_platform->_tgOrder['payed']
            && in_array($this->_platform->_tgOrder['pay_status'], array('0','3','8')) ) {
            
            $last_payment = array_pop($payment_list);
            $master['paytime'] = $last_payment['pay_time'] ? kernel::single('ome_func')->date2time($last_payment['pay_time']) : time();
        }

        $master = array_filter($master,array($this,'filter_null'));

        $diff_master = array_udiff_assoc($master, $this->_platform->_tgOrder,array($this,'comp_array_value'));

        if ($diff_master) {
            $this->_platform->_newOrder = array_merge($this->_platform->_newOrder,$diff_master);

            if (in_array($this->_platform->_newOrder['pay_status'], array('6','7'))) {
               $this->_platform->_newOrder['pause'] = 'true';
            }      
        }

        $payinfo = array();
        $payinfo['pay_name']     = $this->_platform->_ordersdf['payinfo']['pay_name'];
        $payinfo['cost_payment'] = $this->_platform->_ordersdf['payinfo']['cost_payment'];
        $payinfo = array_filter($payinfo,array($this,'filter_null'));
        $diff_payinfo = array_udiff_assoc($payinfo, $this->_platform->_tgOrder['payinfo'],array($this,'comp_array_value'));
        if ($diff_payinfo) {
            $this->_platform->_newOrder['payinfo'] = array_merge((array)$this->_platform->_newOrder['payinfo'],$diff_payinfo);
        }
    }
}

==> patch-4.3.0-ONex-OMS-wms-source-PHP5.6.tar.gz: ShopexErp/app/erpapi/lib/shop/response/components/order/master.php <==
<?php
/**
* 订单主表信息
*
* @author chenping<chenping@shopex.cn>
* @version $Id: master.php 2013-3-12 17:23Z
*/
class erpapi_shop_response_components_order_master extends erpapi_shop_response_components_order_abstract
{
    const _APP_NAME = 'ome';
    /**
     * 订单格式转换
     *
     * @return void
     * @author 
     **/
    public function convert()
    {
        $funcObj = kernel::single('ome_func');

        # 店铺
        $this->_platform->_newOrder['shop_id']   = $this->_platform->__channelObj->channel['shop_id'];
        $this->_platform->_newOrder['shop_type'] = $this->_platform->__channelObj->channel['shop_type'];

        # 订单主信息
        $this->_platform->_newOrder['order_bn']         = $this->_platform->_ordersdf['order_bn'];
        $this->_platform->_newOrder['cost_item']        = (float)$this->_platform->_ordersdf['cost_item'];
        $this->_platform->_newOrder['discount']         = (float)$this->_platform->_ordersdf['discount'];
        $this->_platform->_newOrder['total_amount']     = (float)$this->_platform->_ordersdf['total_amount'];
        $this->_platform->_newOrder['pmt_goods']        = (float)$this->_platform->_ordersdf['pmt_goods'];
        $this->_platform->_newOrder['pmt_order']        = (float)$this->_platform->_ordersdf['pmt_order'];
        $this->_platform->_newOrder['cur_amount']       = (float)$this->_platform->_ordersdf['cur_amount'];
        $this->_platform->_newOrder['score_u']          = (float)$this->_platform->_ordersdf['score_u'];
        $this->_platform->_newOrder['score_g']          = (float)$this->_platform->_ordersdf['score_g'];
        $this->_platform->_newOrder['currency']         = $this->_platform->_ordersdf['currency'] ? $this->_platform->_ordersdf['currency'] : 'CNY';
        $this->_platform->_newOrder['source']           = 'matrix';
        $this->_platform->_newOrder['status']           = $this->_platform->_ordersdf['status'];
        $this->_platform->_newOrder['weight']           = (float)$this->_platform->_ordersdf['weight'];
        $this->_platform->_newOrder['order_source']     = $this->_platform->_ordersdf['order_source'];
        $this->_platform->_newOrder['cur_rate']         = $this->_platform->_ordersdf['cur_rate'] ? $this->_platform->_ordersdf['cur_rate'] : 1;
        $this->_platform->_newOrder['title']            = $this->_platform->_ordersdf['title'];
        $this->_platform->_newOrder['coupons_name']     = $this->_platform->_ordersdf['coupons_name'];
        $this->_platform->_newOrder['createway']        = 'matrix';
        
        $this->_platform->_newOrder['o2o_info']         = $this->_platform->_ordersdf['o2o_info'];
        // 平台运单号
        if ($this->_platform->_ordersdf['shipping']['shipping_id']) {
            $this->_platform->_newOrder['logi_no']          = $this->_platform->_ordersdf['shipping']['shipping_id'];
        }
	$this->_platform->_newOrder['order_type'] = $this->_platform->_ordersdf['order_type'] ? $this->_platform->_ordersdf['order_type'] : 'normal';

        if (isset($this->_platform->_ordersdf['self_delivery'])) $this->_platform->_newOrder['self_delivery']        = $this->_platform->_ordersdf['self_delivery'];

        # 时间
        $this->_platform->_newOrder['download_time']    = time();
        $this->_platform->_newOrder['createtime']       = $funcObj->date2time($this->_platform->_ordersdf['createtime']);
        $outer_lastmodify = $this->_platform->_ordersdf['lastmodify'] ? $this->_platform->_ordersdf['lastmodify'] : time();
        $this->_platform->_newOrder['outer_lastmodify'] = $funcObj->date2time($outer_lastmodify);

        if ($this->_platform->_ordersdf['order_limit_time']) {
            $this->_platform->_newOrder['order_limit_time'] = $funcObj->date2time($this->_platform->_ordersdf['order_limit_time']);
        } else {
            $this->_platform->_newOrder['order_limit_time'] = time() + 60 * (app::get('ome')->getConf('ome.order.failtime'));
        }

        if ($this->_platform->_ordersdf['relate_order_bn']){
            $this->_platform->_newOrder['relate_order_bn'] = $this->_platform->_ordersdf['relate_order_bn'];
        }
        
        # 支付方式
        $payment_cfg             = $this->_platform->get_payment($this->_platform->_ordersdf['pay_bn'],$this->_platform->__channelObj->channel['node_type']);
        $this->_platform->_newOrder['pay_bn']      = $payment_cfg['pay_bn'];
        $this->_platform->_newOrder['pay_status'] =$this->_platform->_ordersdf['pay_status'];
        $this->_platform->_newOrder['payed']      = $this->_platform->_ordersdf['payed'];

        # 支付金额
        $this->_platform->_newOrder['payinfo']['pay_name']     = $this->_platform->_ordersdf['payinfo']['pay_name'];
        $this->_platform->_newOrder['payinfo']['cost_payment'] = $this->_platform->_ordersdf['payinfo']['cost_payment'];

        # 支付单结构
        $payment_list = isset($this->_platform->_ordersdf['payments']) ? $this->_platform->_ordersdf['payments'] : (array)$this->_platform->_ordersdf['payment_detail'];
        if($this->_platform->_ordersdf['payment_detail']){
            $payment_detail = $this->_platform->_ordersdf['payment_detail'];
            unset($this->_platform->_ordersdf['payment_detail']);
            $this->_platform->_ordersdf['payment_detail'][] = $payment_detail;
        }
        if ($payment_list && is_array($payment_list)) {
            $total_amount = $this->_platform->_ordersdf['total_amount'];

            $pay_status = '0';
            $payed      = '0.000';
            $paytime    = null;

            foreach ($payment_list as $key => $value) {
                $payed += $value['money'];
                
                if ($value['pay_time']) {
                    $paytime = kernel::single('ome_func')->date2time($value['pay_time']);
                }
            }

            if ($total_amount <= $payed) {
                $pay_status = '1';

                if (!$paytime) $paytime = time();
            } elseif ($payed <= 0) {
                $pay_status = '0';
            } else {
                if (!$paytime) $paytime = time();

                $comp = bccomp(round($payed,3), $total_amount,3);

                $pay_status = $comp < 0 ? '3' : '1';
            }

            $this->_platform->_newOrder['pay_status'] = $pay_status;
            $this->_platform->_newOrder['payed']      = $payed;
            
            if ($paytime)
                $this->_platform->_newOrder['paytime']    = intval($paytime);
            
        }

        #加入手动单拉订单_标记_防止自动审单 ExBOY
        $this->_platform->_newOrder['auto_combine']    = ($this->_platform->_ordersdf['auto_combine'] === false ? false : true);
        if($this->_platform->_ordersdf['is_service_order']){
            $this->_platform->_newOrder['is_service_order']     = $this->_platform->_ordersdf['is_service_order'];
        }
        
        if ($this->_platform->_ordersdf['order_bool_type']){
            $orderBoolType = $this->_platform->_ordersdf['order_bool_type'];
        }else{
            $orderBoolType = 0;
        }
        if(!empty($this->_platform->_ordersdf['cnAuto'])){
            $this->_platform->_newOrder['cnAuto']           = $this->_platform->_ordersdf['cnAuto'];
            $this->_platform->_newOrder['order_bool_type'] = $this->_platform->_newOrder['order_bool_type'] | ome_order_bool_type::__CNAUTO_CODE;
            $orderBoolType = $orderBoolType | ome_order_bool_type::__CNAUTO_CODE;
            
        }

        // 风控订单
        if ($this->_platform->_ordersdf['is_risk'] == 'true') {
            $orderBoolType = $orderBoolType | ome_order_bool_type::__RISK_CODE;
        }
        // 跨境订单ORDER_TYPE 天猫国际
        if ($this->_platform->_ordersdf['trade_type'] == 'tmall_i18n' || $this->_platform->_ordersdf['t_type'] == 'tmall_i18n') {
            $this->_platform->_newOrder['t_type']           = $this->_platform->_ordersdf['t_type'];
            
            $orderBoolType = $orderBoolType | ome_order_bool_type::__INTERNAL_CODE;
        }

        if ($this->_platform->_ordersdf['cn_info'] && $this->_platform->_ordersdf['cn_info']['cn_service']) {
            $cnBool = kernel::single('ome_order_func')->cnServiceToBool($this->_platform->_ordersdf['cn_info']['cn_service']);
            $orderBoolType = $orderBoolType | $cnBool;
        }
        $this->_platform->_newOrder['order_bool_type'] = $orderBoolType;

        // 平台运单号
        if ($this->_platform->_ordersdf['shipping']['shipping_id']) {
            $this->_platform->_newOrder['platform_logi_no'] = $this->_platform->_ordersdf['shipping']['shipping_id'];
            $this->_platform->_newOrder['logi_no']          = $this->_platform->_ordersdf['shipping']['shipping_id'];
        }
    }

    public function update()
    {
        if (in_array($this->_platform->_tgOrder['pay_status'], array('6','7')) && in_array($this->_platform->_ordersdf['pay_status'], array('1','3','4','5'))) {
            $this->_platform->_newOrder['pause'] = 'false';
        }

        $master = array();

        if ($this->_platform->_ordersdf['order_limit_time']) {
            $order_limit_time = kernel::single('ome_func')->date2time($this->_platform->_ordersdf['order_limit_time']);
            if ($order_limit_time != $this->_platform->_tgOrder['order_limit_time'] && $this->_platform->_tgOrder['pay_status'] == '0') {
                $master['order_limit_time'] = $order_limit_time;
            }
        }

        $master['pay_status']                = $this->_platform->_ordersdf['pay_status'];
        $master['discount']                  = $this->_platform->_ordersdf['discount'];
        $master['pmt_goods']                 = $this->_platform->_ordersdf['pmt_goods'];
        $master['pmt_order']                 = $this->_platform->_ordersdf['pmt_order'];
        $master['total_amount']              = $this->_platform->_ordersdf['total_amount'];
        $master['cur_amount']                = $this->_platform->_ordersdf['cur_amount'];
        $master['payed']                     = $this->_platform->_ordersdf['payed'];
        $master['cost_item']                 = $this->_platform->_ordersdf['cost_item'];
        $master['coupons_name']              = $this->_platform->_ordersdf['coupons_name'];
        $master['is_tax']                    = $this->_platform->_ordersdf['is_tax'] ? $this->_platform->_ordersdf['is_tax'] : 'false';
        $master['tax_no']                    = $this->_platform->_ordersdf['tax_no'];
        $master['cost_tax']                  = $this->_platform->_ordersdf['cost_tax'];
        $master['tax_title']                 = $this->_platform->_ordersdf['tax_title'];
        $master['weight']                    = $this->_platform->_ordersdf['weight'];
        $master['title']                     = $this->_platform->_ordersdf['title'];
        $master['score_u']                   = $this->_platform->_ordersdf['score_u'];
        $master['score_g']                   = $this->_platform->_ordersdf['score_g'];
        $master['status']                    = $this->_platform->_ordersdf['status'];
        
        
        $payment_cfg = $this->_platform->get_payment($this->_platform->_ordersdf['pay_bn'],$this->_platform->__channelObj->channel['node_type']);
        $master['pay_bn'] = $payment_cfg['pay_bn'];

        # 支付单结构
        $payment_list = isset($this->_platform->_ordersdf['payments']) ? $this->_platform->_ordersdf['payments'] : array($this->_platform->_ordersdf['payment_detail']);
        if ($payment_list 
            && is_array($payment_list) 
            && $this->_platform->_ordersdf['payed'] >= $this->_platform->_tgOrder['payed']
            && in_array($this->_platform->_tgOrder['pay_status'], array('0','3','8')) ) {
            
            $last_payment = array_pop($payment_list);
            $master['paytime'] = $last_payment['pay_time'] ? kernel::single('ome_func')->date2time($last_payment['pay_time']) : time();
        }

        $master = array_filter($master,array($this,'filter_null'));

        $diff_master = array_udiff_assoc($master, $this->_platform->_tgOrder,array($this,'comp_array_value'));

        if ($diff_master) {
            $this->_platform->_newOrder = array_merge($this->_platform->_newOrder,$diff_master);

            if (in_array($this->_platform->_newOrder['pay_status'], array('6','7'))) {
               $this->_platform->_newOrder['pause'] = 'true';
            }      
        }

        $payinfo = array();
        $payinfo['pay_name']     = $this->_platform->_ordersdf['payinfo']['pay_name'];
        $payinfo['cost_payment'] = $this->_platform->_ordersdf['payinfo']['cost_payment'];
        $payinfo = array_filter($payinfo,array($this,'filter_null'));
        $diff_payinfo = array_udiff_assoc($payinfo, $this->_platform->_tgOrder['payinfo'],array($this,'comp_array_value'));
        if ($diff_payinfo) {
            $this->_platform->_newOrder['payinfo'] = array_merge((array)$this->_platform->_newOrder['payinfo'],$diff_payinfo);
        }
    }
}
